==> RSTouchscreenNG-1.3.0.zip: RSTouchscreenNG/projects/binding/src/lib/index.ts <==
/* (C) 2016-2021 Hot-World GmbH & Co. KG <rlittwin@repetier.com>
 All Rights Reserved

 THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
 ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY
 DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

 It is allowed to use this code to create or use in products connecting to
 Repetier-Server or to use it for own plugins/modules with Repetier-Server.
 This includes free and commercial products.
 Usage for other products is strictly forbidden.
 */

import {NgModule} from "@angular/core";
import {CommonModule} from "@angular/common";
import {
  Byte,
  Coord,
  Fixed,
  HMS,
  HMSShort,
  DHMS,
  YesNo,
  EqualsPipe,
  SanitizeHtml,
  ToInt,
  TimeShort,
  DateShort,
  DateTimeShort,
  TempReadPipe,
  TempFullPipe, QuickCommandsPipe
} from "./Pipes";
import {RepetierServer} from "./RepetierServer";
import {ConnectionHandler} from "./ConnectionHandler";
import {IfConnectedDirective} from "./directives/ifConnected.directive";
import {IfPrintingDirective} from "./directives/ifPrinting.directive";
import {repetierReducer} from "./reducer/RepetierReducer";
import {RepetierState} from "./state/RepetierState";
import {ConnectionAction} from "./actions/ConnectionAction";
import {ServerAction} from "./actions/ServerAction";
import {LicenseAction} from "./actions/LicenseAction";
import {PrintersAction} from "./actions/PrintersAction";
import {PrinterAction} from "./actions/PrinterAction";
import {UserAction} from "./actions/UserAction";
import {PrinterErrorAction} from "./actions/PrinterErrorAction";
import {WifiAction} from "./actions/WifiAction";
import {MessagesAction} from "./actions/MessagesAction";
import {RSQRCode} from "./QRCode";
import {StoreModule, Store} from "@ngrx/store";
import {StoreDevtoolsModule} from "@ngrx/store-devtools";
declare global {
  interface Window {
    __DEVMODE__: any;
  }
}

@NgModule({
  imports: [CommonModule,
    StoreModule.forRoot(repetierReducer),
    /* StoreDevtoolsModule.instrument({
      maxAge: 25, // Retains last 25 states
      logOnly: !window.__DEVMODE__, // Restrict extension to log-only mode
      autoPause: true // Pauses recording actions and state changes when the extension window is not open
    }) */
  ],
  declarations: [
    IfConnectedDirective,
    IfPrintingDirective,
    Byte,
    Coord,
    Fixed,
    HMS,
    HMSShort,
    DHMS,
    YesNo,
    TimeShort,
    DateShort,
    DateTimeShort,
    EqualsPipe,
    SanitizeHtml,
    ToInt,
    TempReadPipe,
    TempFullPipe,
    QuickCommandsPipe,
    RSQRCode
  ],
  exports: [
    IfConnectedDirective,
    IfPrintingDirective,
    Byte,
    Coord,
    Fixed,
    HMS,
    HMSShort,
    DHMS,
    TimeShort,
    DateShort,
    DateTimeShort,
    YesNo,
    EqualsPipe,
    SanitizeHtml,
    ToInt,
    RSQRCode,
    TempReadPipe,
    TempFullPipe,
    QuickCommandsPipe,
    StoreDevtoolsModule
  ],
  providers: [
    IfConnectedDirective,
    IfPrintingDirective,
    RepetierServer,
    ConnectionAction,
    ServerAction,
    LicenseAction,
    PrintersAction,
    PrinterAction,
    PrinterErrorAction,
    UserAction,
    ConnectionHandler,
    WifiAction,
    MessagesAction
  ]
})
export class RSBindingModule {
  constructor(private ngRedux: Store<RepetierState>,
              private devTools: StoreDevtoolsModule) {
    // You probably only want to expose this tool in devMode.
    /*if (window.__DEVMODE__ ) {
      StoreDevtoolsModule.instrument({maxAge: 25, logOnly: false});
      console.log('NgRx development tools enabled');
    }*/
    // StoreModule.forRoot(repetierReducer);
    // ngRedux.configureStore(repetierReducer, INITIAL_REPETIER_STATE, [], enhancers);
  }
}

export * from "./RepetierServer";
export * from "./ConnectionHandler";
export * from "./Tool";
export * from "./Pipes";
export * from "./RSUtils";
export * from "./BrowseFolder";
export * from "./QRCode";
export * from "./VisualAids";
export * from "./state/RepetierState"; // includes all state files
export * from "./actions/ConnectionAction";
export * from "./actions/ServerAction";
export * from "./actions/UserAction";
export * from "./actions/LicenseAction";
export * from "./actions/PrintersAction";
export * from "./actions/PrinterAction";
export * from "./actions/PrinterErrorAction";
export * from "./actions/WifiAction";
export * from "./actions/MessagesAction";
export * from "./directives/ifConnected.directive";
export * from "./directives/ifPrinting.directive";

==> RSTouchscreenNG-1.4.11.zip: RSTouchscreenNG/projects/binding/src/lib/index.ts <==
/* (C) 2016-2023 Hot-World GmbH & Co. KG <rlittwin@repetier.com>
 All Rights Reserved

 THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
 ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY
 DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

 It is allowed to use this code to create or use in products connecting to
 Repetier-Server or to use it for own plugins/modules with Repetier-Server.
 This includes free and commercial products.
 Usage for other products is strictly forbidden.
 */

import {NgModule} from "@angular/core";
import {CommonModule} from "@angular/common";
import {
  Byte,
  Coord,
  Fixed,
  HMS,
  HMSShort,
  DHMS,
  YesNo,
  EqualsPipe,
  SanitizeHtml,
  ToInt,
  TimeShort,
  DateShort,
  DateTimeShort,
  TempReadPipe,
  TempOffPipe,
  TempFullPipe, QuickCommandsPipe
} from "./Pipes";
import {RepetierServer} from "./RepetierServer";
import {ConnectionHandler} from "./ConnectionHandler";
import {IfConnectedDirective} from "./directives/ifConnected.directive";
import {IfPrintingDirective} from "./directives/ifPrinting.directive";
import {repetierReducer} from "./reducer/RepetierReducer";
import {RepetierState} from "./state/RepetierState";
import {ConnectionAction} from "./actions/ConnectionAction";
import {ServerAction} from "./actions/ServerAction";
import {LicenseAction} from "./actions/LicenseAction";
import {PrintersAction} from "./actions/PrintersAction";
import {PrinterAction} from "./actions/PrinterAction";
import {UserAction} from "./actions/UserAction";
import {PrinterErrorAction} from "./actions/PrinterErrorAction";
import {WifiAction} from "./actions/WifiAction";
import {MessagesAction} from "./actions/MessagesAction";
import {RSQRCode} from "./QRCode";
import {StoreModule, Store} from "@ngrx/store";
import {StoreDevtoolsModule} from "@ngrx/store-devtools";
declare global {
  interface Window {
    __DEVMODE__: any;
  }
}

@NgModule({
  imports: [CommonModule,
    StoreModule.forRoot(repetierReducer, {
      runtimeChecks: {
        strictStateSerializability: false, // set true for testing
        strictActionSerializability: false, // set true for testing
        /* other checks */
      }})
    /* StoreDevtoolsModule.instrument({
      maxAge: 25, // Retains last 25 states
      logOnly: !window.__DEVMODE__, // Restrict extension to log-only mode
      autoPause: true // Pauses recording actions and state changes when the extension window is not open
    }) */
  ],
  declarations: [
    IfConnectedDirective,
    IfPrintingDirective,
    Byte,
    Coord,
    Fixed,
    HMS,
    HMSShort,
    DHMS,
    YesNo,
    TimeShort,
    DateShort,
    DateTimeShort,
    EqualsPipe,
    SanitizeHtml,
    ToInt,
    TempReadPipe,
    TempOffPipe,
    TempFullPipe,
    QuickCommandsPipe,
    RSQRCode
  ],
  exports: [
    IfConnectedDirective,
    IfPrintingDirective,
    Byte,
    Coord,
    Fixed,
    HMS,
    HMSShort,
    DHMS,
    TimeShort,
    DateShort,
    DateTimeShort,
    YesNo,
    EqualsPipe,
    SanitizeHtml,
    ToInt,
    RSQRCode,
    TempReadPipe,
    TempOffPipe,
    TempFullPipe,
    QuickCommandsPipe,
    StoreDevtoolsModule
  ],
  providers: [
    IfConnectedDirective,
    IfPrintingDirective,
    RepetierServer,
    ConnectionAction,
    ServerAction,
    LicenseAction,
    PrintersAction,
    PrinterAction,
    PrinterErrorAction,
    UserAction,
    ConnectionHandler,
    WifiAction,
    MessagesAction
  ]
})
export class RSBindingModule {
  constructor(private ngRedux: Store<RepetierState>,
              private devTools: StoreDevtoolsModule) {
    // You probably only want to expose this tool in devMode.
    /*if (window.__DEVMODE__ ) {
      StoreDevtoolsModule.instrument({maxAge: 25, logOnly: false});
      console.log('NgRx development tools enabled');
    }*/
    // StoreModule.forRoot(repetierReducer);
    // ngRedux.configureStore(repetierReducer, INITIAL_REPETIER_STATE, [], enhancers);
  }
}

export * from "./RepetierServer";
export * from "./ConnectionHandler";
export * from "./Tool";
export * from "./Pipes";
export * from "./RSUtils";
export * from "./BrowseFolder";
export * from "./QRCode";
export * from "./VisualAids";
export * from "./state/RepetierState"; // includes all state files
export * from "./actions/ConnectionAction";
export * from "./actions/ServerAction";
export * from "./actions/UserAction";
export * from "./actions/LicenseAction";
export * from "./actions/PrintersAction";
export * from "./actions/PrinterAction";
export * from "./actions/PrinterErrorAction";
export * from "./actions/WifiAction";
export * from "./actions/MessagesAction";
export * from "./directives/ifConnected.directive";
export * from "./directives/ifPrinting.directive";
export * from "./globalOptions";
